@@ -25,7 +25,7 @@
  * - type: (string) The type of the remote FTP server. Possible values: 'unix',
  *         'win', 'netware' By default, we attempt to auto-detect type.
  *
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  * Copyright 2002-2007 Michael Varghese <mike.varghese@ascellatech.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
@@ -223,7 +223,7 @@ class Horde_Vfs_Ftp extends Horde_Vfs_Base
     public function write($path, $name, $tmpFile, $autocreate = false)
     {
         $this->_connect();
-        $this->_checkQuotaWrite('file', $tmpFile);
+        $this->_checkQuotaWrite('file', $tmpFile, $path, $name);
 
         if (!@ftp_put($this->_stream, $this->_getPath($path, $name), $tmpFile, FTP_BINARY)) {
             if ($autocreate) {
@@ -249,7 +249,6 @@ class Horde_Vfs_Ftp extends Horde_Vfs_Base
      */
     public function writeData($path, $name, $data, $autocreate = false)
     {
-        $this->_checkQuotaWrite('string', $data);
         $tmpFile = Horde_Util::getTempFile('vfs');
         file_put_contents($tmpFile, $data);
         try {
@@ -673,7 +672,7 @@ class Horde_Vfs_Ftp extends Horde_Vfs_Base
             }
 
             clearstatcache();
-            $this->_checkQuotaWrite('file', $tmpFile);
+            $this->_checkQuotaWrite('file', $tmpFile, $dest, $name);
 
             if (!@ftp_put($this->_stream, $this->_getPath($dest, $name), $tmpFile, FTP_BINARY)) {
                 unlink($tmpFile);
