@@ -2,7 +2,7 @@
 /**
  * Class for providing garbage collection for any VFS instance.
  *
- * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -20,7 +20,7 @@ class Horde_Vfs_Gc
      * @param integer $secs  The minimum amount of time (in seconds) required
      *                       before a file is removed.
      */
-    public function gc($vfs, $path, $secs = 345600)
+    public static function gc($vfs, $path, $secs = 345600)
     {
         /* A 0.1% chance we will run garbage collection during a call. */
         if (substr(time(), -3) !== '000') {
