@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Vfs
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Vfs
  */
@@ -176,7 +176,7 @@ class Horde_Vfs_Mongo extends Horde_Vfs_Base
      */
     protected function _write($type, $path, $name, $data, $autocreate)
     {
-        $this->_checkQuotaWrite($type, $data);
+        $this->_checkQuotaWrite($type, $data, $path, $name);
 
         if ($autocreate) {
             $this->autocreatePath($path);
