@@ -2,7 +2,7 @@
 /**
  * Test the FTP based virtual file system.
  *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -160,7 +160,12 @@ class Horde_Vfs_FtpTest extends Horde_Vfs_TestBase
         $this->_listFolder();
     }
 
-    static public function setUpBeforeClass()
+    public function testChmod()
+    {
+        $this->_chmod();
+    }
+
+    public static function setUpBeforeClass()
     {
         if (!extension_loaded('ftp')) {
             self::$reason = 'No ftp extension';
@@ -174,7 +179,7 @@ class Horde_Vfs_FtpTest extends Horde_Vfs_TestBase
         }
     }
 
-    static public function tearDownAfterClass()
+    public static function tearDownAfterClass()
     {
         if (self::$vfs) {
             try {
