@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -181,7 +181,7 @@ class Horde_Vfs_MongoTest extends Horde_Vfs_TestBase
         $this->_listFolder();
     }
 
-    static public function setUpBeforeClass()
+    public static function setUpBeforeClass()
     {
         if (($config = self::getConfig('VFS_MONGO_TEST_CONFIG', __DIR__)) &&
             isset($config['vfs']['mongo']['hostspec'])) {
@@ -201,7 +201,7 @@ class Horde_Vfs_MongoTest extends Horde_Vfs_TestBase
         }
     }
 
-    static public function tearDownAfterClass()
+    public static function tearDownAfterClass()
     {
         if (!empty(self::$_mongo)) {
             self::$_mongo->selectDB(null)->drop();
