@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Jan Schneider <jan@horde.org>
  * @category   Horde
@@ -175,7 +175,7 @@ class Horde_Vfs_Test_Sql_Base extends Horde_Vfs_TestBase
             self::$db,
             null,//$logger,
             array('migrationsPath' => $dir,
-                  'schemaTableName' => 'horde_vfs_test_schema'));
+                  'schemaTableName' => 'horde_vfs_schema_info'));
         self::$migrator->up();
 
         self::$vfs = new Horde_Vfs_Sql(array('db' => self::$db));
